@@ -23,7 +23,7 @@ Usage::
     describe_job_queues_paginator: DescribeJobQueuesPaginator = client.get_paginator("describe_job_queues")
     list_jobs_paginator: ListJobsPaginator = client.get_paginator("list_jobs")
 """
-from mypy_boto3_batch.client import BatchClient as Client, BatchClient
+from mypy_boto3_batch.client import BatchClient, BatchClient as Client
 from mypy_boto3_batch.paginator import (
     DescribeComputeEnvironmentsPaginator,
     DescribeJobDefinitionsPaginator,
