@@ -1,6 +1,12 @@
-"Main interface for batch service type defs"
-from __future__ import annotations
+"""
+Main interface for batch service type definitions.
 
+Usage::
+
+    from mypy_boto3.batch.type_defs import ArrayPropertiesTypeDef
+
+    data: ArrayPropertiesTypeDef = {...}
+"""
 import sys
 from typing import Dict, List
 
@@ -14,6 +20,57 @@ else:
     from typing_extensions import TypedDict
 
 
+__all__ = (
+    "ArrayPropertiesTypeDef",
+    "ComputeEnvironmentOrderTypeDef",
+    "LaunchTemplateSpecificationTypeDef",
+    "ComputeResourceTypeDef",
+    "ComputeResourceUpdateTypeDef",
+    "KeyValuePairTypeDef",
+    "ResourceRequirementTypeDef",
+    "ContainerOverridesTypeDef",
+    "DeviceTypeDef",
+    "LinuxParametersTypeDef",
+    "MountPointTypeDef",
+    "UlimitTypeDef",
+    "HostTypeDef",
+    "VolumeTypeDef",
+    "ContainerPropertiesTypeDef",
+    "CreateComputeEnvironmentResponseTypeDef",
+    "CreateJobQueueResponseTypeDef",
+    "ComputeEnvironmentDetailTypeDef",
+    "DescribeComputeEnvironmentsResponseTypeDef",
+    "JobTimeoutTypeDef",
+    "NodeRangePropertyTypeDef",
+    "NodePropertiesTypeDef",
+    "RetryStrategyTypeDef",
+    "JobDefinitionTypeDef",
+    "DescribeJobDefinitionsResponseTypeDef",
+    "JobQueueDetailTypeDef",
+    "DescribeJobQueuesResponseTypeDef",
+    "ArrayPropertiesDetailTypeDef",
+    "NetworkInterfaceTypeDef",
+    "AttemptContainerDetailTypeDef",
+    "AttemptDetailTypeDef",
+    "ContainerDetailTypeDef",
+    "JobDependencyTypeDef",
+    "NodeDetailsTypeDef",
+    "JobDetailTypeDef",
+    "DescribeJobsResponseTypeDef",
+    "ArrayPropertiesSummaryTypeDef",
+    "ContainerSummaryTypeDef",
+    "NodePropertiesSummaryTypeDef",
+    "JobSummaryTypeDef",
+    "ListJobsResponseTypeDef",
+    "NodePropertyOverrideTypeDef",
+    "NodeOverridesTypeDef",
+    "PaginatorConfigTypeDef",
+    "RegisterJobDefinitionResponseTypeDef",
+    "SubmitJobResponseTypeDef",
+    "UpdateComputeEnvironmentResponseTypeDef",
+    "UpdateJobQueueResponseTypeDef",
+)
+
 ArrayPropertiesTypeDef = TypedDict("ArrayPropertiesTypeDef", {"size": int}, total=False)
 
 ComputeEnvironmentOrderTypeDef = TypedDict(
